import boto3
from . import constant as constant

ecs_client = boto3.client('ecs')

def get_services_from_cluster(cluster_name, max_results=100):
    return ecs_client.list_services(
        cluster=cluster_name,
        maxResults=max_results
    )

def get_services_arn_from_query(q, cluster_name):
    founded_services = []
    services = get_services_from_cluster(cluster_name)
    for service_arn in services['serviceArns']:
        if q.upper() in service_arn.upper():
            founded_services.append(service_arn)
    return founded_services

# Récupère les arn de tous les services ecs d'un cluster pour une couleur donnée
def get_services_arn_for_color(color, cluster_name):
    colored_services = []
    services = get_services_from_cluster(cluster_name)
    for service_arn in services['serviceArns']:
        if color in service_arn.upper():
            colored_services.append(service_arn)
    return colored_services


def get_service_max_capacity_from_service_arn(service_arn):
    tag_description_result = ecs_client.list_tags_for_resource(resourceArn=service_arn)
    tags = tag_description_result.get('tags')
    max_capacity_value = None
    for i in range(len(tags)):
        if tags[i].get("key") == "MaxCapacity":
            max_capacity_value = int(tags[i].get("value"))
            break

    return max_capacity_value or constant.DEFAULT_MAX_CAPACITY


def get_service_resource_id_from_service_arn(service_arn):
    return str(service_arn).split(':')[5]


import boto3
from . import constant as constant

ecr_client = boto3.client('ecr')


# Récupère le nom des ECR qui sont des services
# Un service commence par 'lcdp-'
def get_service_repositories_name():
    repositories = ecr_client.describe_repositories()
    service_repositories = []
    for repository in repositories['repositories']:
        if repository['repositoryName'].startswith(constant.ECR_SERVICE_PREFIX):
            service_repositories.append(repository['repositoryName'])
    return service_repositories


# Récupère une image possédant un tag précis
def get_repository_image_for_tag(repository_name, tag):
    images = ecr_client.list_images(
        repositoryName=repository_name,
        # TODO: Review if one day we got more than 1000 ecr images !
        maxResults=1000
    )
    for image in images['imageIds']:
        if 'imageTag' in image and image['imageTag'] == tag:
            return image


# Récupère le manifest d'une image
def get_image_manifest(repository_name, image):
    detailed_image = ecr_client.batch_get_image(
        repositoryName=repository_name,
        imageIds=[image]
    )
    return detailed_image['images'][0]['imageManifest']




# Démarre tous les services d'un environement et attend qu'il soit entièrement up
def start_environment_and_wait_for_health(environment):
    environment.start_up_services()
    environment.wait_for_services_health()


# Passe d'un environnement à l'autre en modifiant les targets groups des règles du listener
def do_balancing(deployment_manager, from_environment, to_environment):
    print("Do balancing from environment {} to environment {}".format(from_environment.color, to_environment.color))
    deployment_manager.update_rule_target_group(
        expected_rule_type=from_environment.target_group_type,
        expected_rule_color=from_environment.color,
        new_target_group_arn=to_environment.target_group_arn
    )
